Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CompileAndInspect ¶
CompileAndInspect compiles the program and dumps the opcode in a user friendly format.
func CompileAndSave ¶
CompileAndSave will compile and save the file to disk.
Types ¶
type Options ¶
type Options struct {
// The extension of the output file default set to .avm
Ext string
// The name of the output file.
Outfile string
// Debug will output an hex encoded string of the generated bytecode.
Debug bool
}
Options contains all the parameters that affect the behaviour of the compiler.
Click to show internal directories.
Click to hide internal directories.