Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Account ¶
type Account struct {
// NEO public address.
Address string `json:"address"`
// Encrypted WIF of the account also known as the key.
EncryptedWIF string `json:"key"`
// Label is a label the user had made for this account.
Label string `json:"label"`
// contract is a Contract object which describes the details of the contract.
// This field can be null (for watch-only address).
Contract *Contract `json:"contract"`
// Indicates whether the account is locked by the user.
// the client shouldn't spend the funds in a locked account.
Locked bool `json:"lock"`
// Indicates whether the account is the default change account.
Default bool `json:"isDefault"`
// contains filtered or unexported fields
}
Account represents a NEO account. It holds the private and public key along with some metadata.
func DecryptAccount ¶
DecryptAccount decrypt the encryptedWIF with the given passphrase and return the decrypted Account.
func NewAccount ¶
NewAccount creates a new Account with a random generated PrivateKey.
func NewAccountFromWIF ¶
NewAccountFromWIF creates a new Account from the given WIF.
type Contract ¶
type Contract struct {
// Script hash of the contract deployed on the blockchain.
Script util.Uint160 `json:"script"`
// A list of parameters used deploying this contract.
Parameters []interface{} `json:"parameters"`
// Indicates whether the contract has been deployed to the blockchain.
Deployed bool `json:"deployed"`
}
Contract represents a subset of the smartcontract to embed in the Account so it's NEP-6 compliant.
type Wallet ¶
type Wallet struct {
// Version of the wallet, used for later upgrades.
Version string `json:"version"`
// A list of accounts which describes the details of each account
// in the wallet.
Accounts []*Account `json:"accounts"`
Scrypt keys.ScryptParams `json:"scrypt"`
// Extra metadata can be used for storing arbitrary data.
// This field can be empty.
Extra interface{} `json:"extra"`
// contains filtered or unexported fields
}
Wallet represents a NEO (NEP-2, NEP-6) compliant wallet.
func NewWalletFromFile ¶
NewWalletFromFile creates a Wallet from the given wallet file path
func (*Wallet) AddAccount ¶
AddAccount adds an existing Account to the wallet.
func (*Wallet) Close ¶
func (w *Wallet) Close()
Close closes the internal rw if its an io.ReadCloser.
func (*Wallet) CreateAccount ¶
CreateAccount generates a new account for the end user and encrypts the private key with the given passphrase.